[![Git](https://git-scm.com/images/logo@2x.png)](https://git-scm.com/) --local-branching-on-the-cheap
![](https://git-scm.com/images/dark-mode.svg)
  * [About](https://git-scm.com/about)
    * [Trademark](https://git-scm.com/about/trademark)
  * [Learn](https://git-scm.com/learn)
    * [Book](https://git-scm.com/book)
    * [Cheat Sheet](https://git-scm.com/cheat-sheet)
    * [Videos](https://git-scm.com/videos)
    * [External Links](https://git-scm.com/doc/ext)
  * [Tools](https://git-scm.com/tools)
    * [Command Line](https://git-scm.com/tools/command-line)
    * [GUIs](https://git-scm.com/tools/guis)
    * [Hosting](https://git-scm.com/tools/hosting)
  * [Reference](https://git-scm.com/docs)
  * [Install](https://git-scm.com/install/linux)
  * [Community](https://git-scm.com/community)


  * Table of Contents
    * [NAME](https://git-scm.com/docs/git-help#_name)
    * [SYNOPSIS](https://git-scm.com/docs/git-help#_synopsis)
    * [DESCRIPTION](https://git-scm.com/docs/git-help#_description)
    * [OPTIONS](https://git-scm.com/docs/git-help#_options)
    * [CONFIGURATION VARIABLES](https://git-scm.com/docs/git-help#_configuration_variables)
    * [GIT](https://git-scm.com/docs/git-help#_git)


[ English ▾](https://git-scm.com/docs/git-help)
Localized versions of **git-help** manual
  1. [English ](https://git-scm.com/docs/git-help)
  2. [Français ](https://git-scm.com/docs/git-help/fr)
  3. [Português (Brasil) ](https://git-scm.com/docs/git-help/pt_BR)
  4. [Svenska ](https://git-scm.com/docs/git-help/sv)
  5. [українська мова ](https://git-scm.com/docs/git-help/uk)
  6. [简体中文 ](https://git-scm.com/docs/git-help/zh_HANS-CN)

Want to read in your language or fix typos?
[You can help translate this page](https://github.com/jnavila/git-manpages-l10n).
[Topics ▾](https://git-scm.com/docs/git-help)
### Setup and Config
  * [ git ](https://git-scm.com/docs/git)
  * [ config ](https://git-scm.com/docs/git-config)
  * [ help ](https://git-scm.com/docs/git-help)
  * [ bugreport ](https://git-scm.com/docs/git-bugreport)
  * [ Credential helpers ](https://git-scm.com/doc/credential-helpers)


### Getting and Creating Projects
  * [ init ](https://git-scm.com/docs/git-init)
  * [ clone ](https://git-scm.com/docs/git-clone)


### Basic Snapshotting
  * [ add ](https://git-scm.com/docs/git-add)
  * [ status ](https://git-scm.com/docs/git-status)
  * [ diff ](https://git-scm.com/docs/git-diff)
  * [ commit ](https://git-scm.com/docs/git-commit)
  * [ notes ](https://git-scm.com/docs/git-notes)
  * [ restore ](https://git-scm.com/docs/git-restore)
  * [ reset ](https://git-scm.com/docs/git-reset)
  * [ rm ](https://git-scm.com/docs/git-rm)
  * [ mv ](https://git-scm.com/docs/git-mv)


### Branching and Merging
  * [ branch ](https://git-scm.com/docs/git-branch)
  * [ checkout ](https://git-scm.com/docs/git-checkout)
  * [ switch ](https://git-scm.com/docs/git-switch)
  * [ merge ](https://git-scm.com/docs/git-merge)
  * [ mergetool ](https://git-scm.com/docs/git-mergetool)
  * [ log ](https://git-scm.com/docs/git-log)
  * [ stash ](https://git-scm.com/docs/git-stash)
  * [ tag ](https://git-scm.com/docs/git-tag)
  * [ worktree ](https://git-scm.com/docs/git-worktree)


### Sharing and Updating Projects
  * [ fetch ](https://git-scm.com/docs/git-fetch)
  * [ pull ](https://git-scm.com/docs/git-pull)
  * [ push ](https://git-scm.com/docs/git-push)
  * [ remote ](https://git-scm.com/docs/git-remote)
  * [ submodule ](https://git-scm.com/docs/git-submodule)


### Inspection and Comparison
  * [ show ](https://git-scm.com/docs/git-show)
  * [ log ](https://git-scm.com/docs/git-log)
  * [ diff ](https://git-scm.com/docs/git-diff)
  * [ difftool ](https://git-scm.com/docs/git-difftool)
  * [ range-diff ](https://git-scm.com/docs/git-range-diff)
  * [ shortlog ](https://git-scm.com/docs/git-shortlog)
  * [ describe ](https://git-scm.com/docs/git-describe)


### Patching
  * [ apply ](https://git-scm.com/docs/git-apply)
  * [ cherry-pick ](https://git-scm.com/docs/git-cherry-pick)
  * [ diff ](https://git-scm.com/docs/git-diff)
  * [ rebase ](https://git-scm.com/docs/git-rebase)
  * [ revert ](https://git-scm.com/docs/git-revert)


### Debugging
  * [ bisect ](https://git-scm.com/docs/git-bisect)
  * [ blame ](https://git-scm.com/docs/git-blame)
  * [ grep ](https://git-scm.com/docs/git-grep)


### Email
  * [ am ](https://git-scm.com/docs/git-am)
  * [ apply ](https://git-scm.com/docs/git-apply)
  * [ imap-send ](https://git-scm.com/docs/git-imap-send)
  * [ format-patch ](https://git-scm.com/docs/git-format-patch)
  * [ send-email ](https://git-scm.com/docs/git-send-email)
  * [ request-pull ](https://git-scm.com/docs/git-request-pull)


### External Systems
  * [ svn ](https://git-scm.com/docs/git-svn)
  * [ fast-import ](https://git-scm.com/docs/git-fast-import)


### Server Admin
  * [ daemon ](https://git-scm.com/docs/git-daemon)
  * [ update-server-info ](https://git-scm.com/docs/git-update-server-info)


### Guides
  * [ gitattributes ](https://git-scm.com/docs/gitattributes)
  * [ Command-line interface conventions ](https://git-scm.com/docs/gitcli)
  * [ Everyday Git ](https://git-scm.com/docs/giteveryday)
  * [ Frequently Asked Questions (FAQ) ](https://git-scm.com/docs/gitfaq)
  * [ Glossary ](https://git-scm.com/docs/gitglossary)
  * [ Hooks ](https://git-scm.com/docs/githooks)
  * [ gitignore ](https://git-scm.com/docs/gitignore)
  * [ gitmodules ](https://git-scm.com/docs/gitmodules)
  * [ Revisions ](https://git-scm.com/docs/gitrevisions)
  * [ Submodules ](https://git-scm.com/docs/gitsubmodules)
  * [ Tutorial ](https://git-scm.com/docs/gittutorial)
  * [ Workflows ](https://git-scm.com/docs/gitworkflows)
  * [ All guides... ](https://git-scm.com/docs/git#_guides)


### Administration
  * [ clean ](https://git-scm.com/docs/git-clean)
  * [ gc ](https://git-scm.com/docs/git-gc)
  * [ fsck ](https://git-scm.com/docs/git-fsck)
  * [ reflog ](https://git-scm.com/docs/git-reflog)
  * [ filter-branch ](https://git-scm.com/docs/git-filter-branch)
  * [ instaweb ](https://git-scm.com/docs/git-instaweb)
  * [ archive ](https://git-scm.com/docs/git-archive)
  * [ bundle ](https://git-scm.com/docs/git-bundle)


### Plumbing Commands
  * [ cat-file ](https://git-scm.com/docs/git-cat-file)
  * [ check-ignore ](https://git-scm.com/docs/git-check-ignore)
  * [ checkout-index ](https://git-scm.com/docs/git-checkout-index)
  * [ commit-tree ](https://git-scm.com/docs/git-commit-tree)
  * [ count-objects ](https://git-scm.com/docs/git-count-objects)
  * [ diff-index ](https://git-scm.com/docs/git-diff-index)
  * [ for-each-ref ](https://git-scm.com/docs/git-for-each-ref)
  * [ hash-object ](https://git-scm.com/docs/git-hash-object)
  * [ ls-files ](https://git-scm.com/docs/git-ls-files)
  * [ ls-tree ](https://git-scm.com/docs/git-ls-tree)
  * [ merge-base ](https://git-scm.com/docs/git-merge-base)
  * [ read-tree ](https://git-scm.com/docs/git-read-tree)
  * [ rev-list ](https://git-scm.com/docs/git-rev-list)
  * [ rev-parse ](https://git-scm.com/docs/git-rev-parse)
  * [ show-ref ](https://git-scm.com/docs/git-show-ref)
  * [ symbolic-ref ](https://git-scm.com/docs/git-symbolic-ref)
  * [ update-index ](https://git-scm.com/docs/git-update-index)
  * [ update-ref ](https://git-scm.com/docs/git-update-ref)
  * [ verify-pack ](https://git-scm.com/docs/git-verify-pack)
  * [ write-tree ](https://git-scm.com/docs/git-write-tree)


[ Latest version ▾ ](https://git-scm.com/docs/git-help) git-help last updated in 2.43.0
Changes in the **git-help** manual
  1. 2.43.1 → 2.53.0 no changes
  2. [2.43.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2023-11-20_ ](https://git-scm.com/docs/git-help/2.43.0)
  3. 2.38.1 → 2.42.4 no changes
  4. [2.38.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-10-02_ ](https://git-scm.com/docs/git-help/2.38.0)
  5. 2.36.1 → 2.37.7 no changes
  6. [2.36.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-04-18_ ](https://git-scm.com/docs/git-help/2.36.0)
  7. 2.35.1 → 2.35.8 no changes
  8. [2.35.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-01-24_ ](https://git-scm.com/docs/git-help/2.35.0)
  9. 2.34.1 → 2.34.8 no changes
  10. [2.34.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2021-11-15_ ](https://git-scm.com/docs/git-help/2.34.0)
  11. 2.29.1 → 2.33.8 no changes
  12. [2.29.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-10-19_ ](https://git-scm.com/docs/git-help/2.29.0)
  13. 2.22.1 → 2.28.1 no changes
  14. [2.22.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-06-07_ ](https://git-scm.com/docs/git-help/2.22.0)
  15. 2.21.1 → 2.21.4 no changes
  16. [2.21.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-02-24_ ](https://git-scm.com/docs/git-help/2.21.0)
  17. 2.20.1 → 2.20.5 no changes
  18. [2.20.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2018-12-09_ ](https://git-scm.com/docs/git-help/2.20.0)
  19. 2.19.1 → 2.19.6 no changes
  20. [2.19.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2018-09-10_ ](https://git-scm.com/docs/git-help/2.19.0)
  21. 2.18.1 → 2.18.5 no changes
  22. [2.18.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2018-06-21_ ](https://git-scm.com/docs/git-help/2.18.0)
  23. 2.10.5 → 2.17.6 no changes
  24. [2.9.5 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-07-30_ ](https://git-scm.com/docs/git-help/2.9.5)
  25. 2.2.3 → 2.8.6 no changes
  26. [2.1.4 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2014-12-17_ ](https://git-scm.com/docs/git-help/2.1.4)
  27. [2.0.5 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2014-12-17_ ](https://git-scm.com/docs/git-help/2.0.5)


Check your version of git by running
`git --version`
##  [](https://git-scm.com/docs/git-help#_name)NAME
git-help - Display help information about Git
##  [](https://git-scm.com/docs/git-help#_synopsis)SYNOPSIS
```
_git help_ [-a|--all] [--[no-]verbose] [--[no-]external-commands] [--[no-]aliases]
_git help_ [[-i|--info] [-m|--man] [-w|--web]] [<command>|<doc>]
_git help_ [-g|--guides]
_git help_ [-c|--config]
_git help_ [--user-interfaces]
_git help_ [--developer-interfaces]
```

##  [](https://git-scm.com/docs/git-help#_description)DESCRIPTION
With no options and no _< command>_ or _< doc>_ given, the synopsis of the _git_ command and a list of the most commonly used Git commands are printed on the standard output.
If the option `--all` or `-a` is given, all available commands are printed on the standard output.
If the option `--guides` or `-g` is given, a list of the Git concept guides is also printed on the standard output.
If a command or other documentation is given, the relevant manual page will be brought up. The _man_ program is used by default for this purpose, but this can be overridden by other options or configuration variables.
If an alias is given, git shows the definition of the alias on standard output. To get the manual page for the aliased command, use `git` _< command>_ `--help`.
Note that `git` `--help` ... is identical to `git` `help` ... because the former is internally converted into the latter.
To display the [git[1]](https://git-scm.com/docs/git) man page, use `git` `help` `git`.
This page can be displayed with _git help help_ or `git` `help` `--help`.
##  [](https://git-scm.com/docs/git-help#_options)OPTIONS

[](https://git-scm.com/docs/git-help#Documentation/git-help.txt--a)-a


[](https://git-scm.com/docs/git-help#Documentation/git-help.txt---all)--all

Print all the available commands on the standard output.

[](https://git-scm.com/docs/git-help#Documentation/git-help.txt---no-external-commands)--no-external-commands

When used with `--all`, exclude the listing of external "git-*" commands found in the `$PATH`.

[](https://git-scm.com/docs/git-help#Documentation/git-help.txt---no-aliases)--no-aliases

When used with `--all`, exclude the listing of configured aliases.

[](https://git-scm.com/docs/git-help#Documentation/git-help.txt---verbose)--verbose

When used with `--all`, print description for all recognized commands. This is the default.

[](https://git-scm.com/docs/git-help#Documentation/git-help.txt--c)-c


[](https://git-scm.com/docs/git-help#Documentation/git-help.txt---config)--config

List all available configuration variables. This is a short summary of the list in [git-config[1]](https://git-scm.com/docs/git-config).

[](https://git-scm.com/docs/git-help#Documentation/git-help.txt--g)-g


[](https://git-scm.com/docs/git-help#Documentation/git-help.txt---guides)--guides

Print a list of the Git concept guides on the standard output.

[](https://git-scm.com/docs/git-help#Documentation/git-help.txt---user-interfaces)--user-interfaces

Print a list of the repository, command and file interfaces documentation on the standard output.
In-repository file interfaces such as `.git/info/exclude` are documented here (see [gitrepository-layout[5]](https://git-scm.com/docs/gitrepository-layout)), as well as in-tree configuration such as `.mailmap` (see [gitmailmap[5]](https://git-scm.com/docs/gitmailmap)).
This section of the documentation also covers general or widespread user-interface conventions (e.g. [gitcli[7]](https://git-scm.com/docs/gitcli)), and pseudo-configuration such as the file-based `.git/hooks/*` interface described in [githooks[5]](https://git-scm.com/docs/githooks).

[](https://git-scm.com/docs/git-help#Documentation/git-help.txt---developer-interfaces)--developer-interfaces

Print a list of file formats, protocols and other developer interfaces documentation on the standard output.

[](https://git-scm.com/docs/git-help#Documentation/git-help.txt--i)-i


[](https://git-scm.com/docs/git-help#Documentation/git-help.txt---info)--info

Display manual page for the command in the _info_ format. The _info_ program will be used for that purpose.

[](https://git-scm.com/docs/git-help#Documentation/git-help.txt--m)-m


[](https://git-scm.com/docs/git-help#Documentation/git-help.txt---man)--man

Display manual page for the command in the _man_ format. This option may be used to override a value set in the `help.format` configuration variable.
By default the _man_ program will be used to display the manual page, but the `man.viewer` configuration variable may be used to choose other display programs (see below).

[](https://git-scm.com/docs/git-help#Documentation/git-help.txt--w)-w


[](https://git-scm.com/docs/git-help#Documentation/git-help.txt---web)--web

Display manual page for the command in the _web_ (HTML) format. A web browser will be used for that purpose.
The web browser can be specified using the configuration variable `help.browser`, or `web.browser` if the former is not set. If neither of these config variables is set, the _git web--browse_ helper script (called by _git help_) will pick a suitable default. See [git-web--browse[1]](https://git-scm.com/docs/git-web--browse) for more information about this.
##  [](https://git-scm.com/docs/git-help#_configuration_variables)CONFIGURATION VARIABLES
###  [](https://git-scm.com/docs/git-help#_help_format)help.format
If no command-line option is passed, the `help.format` configuration variable will be checked. The following values are supported for this variable; they make _git help_ behave as their corresponding command- line option:
  * "man" corresponds to _-m|--man_ ,
  * "info" corresponds to _-i|--info_ ,
  * "web" or "html" correspond to _-w|--web_.


###  [](https://git-scm.com/docs/git-help#_help_browser_web_browser_and_browser_tool_path)help.browser, web.browser, and browser.<tool>.path
The `help.browser`, `web.browser` and `browser.`_< tool>_`.path` will also be checked if the _web_ format is chosen (either by command-line option or configuration variable). See _-w|--web_ in the OPTIONS section above and [git-web--browse[1]](https://git-scm.com/docs/git-web--browse).
###  [](https://git-scm.com/docs/git-help#_man_viewer)man.viewer
The `man.viewer` configuration variable will be checked if the _man_ format is chosen. The following values are currently supported:
  * "man": use the _man_ program as usual,
  * "woman": use _emacsclient_ to launch the "woman" mode in emacs (this only works starting with emacsclient versions 22),
  * "konqueror": use _kfmclient_ to open the man page in a new konqueror tab (see _Note about konqueror_ below).


Values for other tools can be used if there is a corresponding `man.`_< tool>_`.cmd` configuration entry (see below).
Multiple values may be given to the `man.viewer` configuration variable. Their corresponding programs will be tried in the order listed in the configuration file.
For example, this configuration:
```
	[man]
		viewer = konqueror
		viewer = woman
```

will try to use konqueror first. But this may fail (for example, if DISPLAY is not set) and in that case emacs' woman mode will be tried.
If everything fails, or if no viewer is configured, the viewer specified in the `GIT_MAN_VIEWER` environment variable will be tried. If that fails too, the _man_ program will be tried anyway.
###  [](https://git-scm.com/docs/git-help#_man_tool_path)man.<tool>.path
You can explicitly provide a full path to your preferred man viewer by setting the configuration variable `man.`_< tool>_`.path`. For example, you can configure the absolute path to konqueror by setting _man.konqueror.path_. Otherwise, _git help_ assumes the tool is available in PATH.
###  [](https://git-scm.com/docs/git-help#_man_tool_cmd)man.<tool>.cmd
When the man viewer, specified by the `man.viewer` configuration variables, is not among the supported ones, then the corresponding `man.`_< tool>_`.cmd` configuration variable will be looked up. If this variable exists then the specified tool will be treated as a custom command and a shell eval will be used to run the command with the man page passed as arguments.
###  [](https://git-scm.com/docs/git-help#_note_about_konqueror)Note about konqueror
When _konqueror_ is specified in the `man.viewer` configuration variable, we launch _kfmclient_ to try to open the man page on an already opened konqueror in a new tab if possible.
For consistency, we also try such a trick if _man.konqueror.path_ is set to something like `A_PATH_TO/konqueror`. That means we will try to launch `A_PATH_TO/kfmclient` instead.
If you really want to use _konqueror_ , then you can use something like the following:
```
	[man]
		viewer = konq

	[man "konq"]
		cmd = A_PATH_TO/konqueror
```

###  [](https://git-scm.com/docs/git-help#_note_about_git_config_global)Note about git config --global
Note that all these configuration variables should probably be set using the `--global` flag, for example like this:
```
$ git config --global help.format web
$ git config --global web.browser firefox
```

as they are probably more user specific than repository specific. See [git-config[1]](https://git-scm.com/docs/git-config) for more information about this.
##  [](https://git-scm.com/docs/git-help#_git)GIT
Part of the [git[1]](https://git-scm.com/docs/git) suite
### help
[About this site](https://git-scm.com/site)
Patches, suggestions, and comments are welcome.
Git is a member of [Software Freedom Conservancy](https://git-scm.com/sfc)
